@@ -7,6 +7,8 @@ else
 fi
 ( cd opt/kde/bin ; rm -rf kfmexec )
 ( cd opt/kde/bin ; ln -sf kioexec kfmexec )
+( cd opt/kde/bin ; rm -rf filesharelist )
+( cd opt/kde/bin ; ln -sf fileshareset filesharelist )
 ( cd opt/kde/lib ; rm -rf libkabc_ldapkio.so )
 ( cd opt/kde/lib ; ln -sf libkabc_ldapkio.so.1.0.0 libkabc_ldapkio.so )
 ( cd opt/kde/lib ; rm -rf libkdeprint.so.4 )
@@ -33,6 +35,8 @@ fi
 ( cd opt/kde/lib ; ln -sf libkutils.so.1.2.0 libkutils.so.1 )
 ( cd opt/kde/lib ; rm -rf libkabc_dir.so )
 ( cd opt/kde/lib ; ln -sf libkabc_dir.so.1.0.0 libkabc_dir.so )
+( cd opt/kde/lib ; rm -rf libknewstuff.so )
+( cd opt/kde/lib ; ln -sf libknewstuff.so.1.0.0 libknewstuff.so )
 ( cd opt/kde/lib ; rm -rf libkdeprint_management.so )
 ( cd opt/kde/lib ; ln -sf libkdeprint_management.so.4.2.0 libkdeprint_management.so )
 ( cd opt/kde/lib ; rm -rf libkjs.so.1 )
@@ -41,6 +45,8 @@ fi
 ( cd opt/kde/lib ; ln -sf libkwalletbackend.so.1.0.0 libkwalletbackend.so )
 ( cd opt/kde/lib ; rm -rf libkdeui.so.4 )
 ( cd opt/kde/lib ; ln -sf libkdeui.so.4.2.0 libkdeui.so.4 )
+( cd opt/kde/lib ; rm -rf libkimproxy.so )
+( cd opt/kde/lib ; ln -sf libkimproxy.so.0.0.0 libkimproxy.so )
 ( cd opt/kde/lib ; rm -rf libkdefx.so )
 ( cd opt/kde/lib ; ln -sf libkdefx.so.4.2.0 libkdefx.so )
 ( cd opt/kde/lib ; rm -rf libkdefx.so.4 )
@@ -51,8 +57,12 @@ fi
 ( cd opt/kde/lib ; ln -sf libkdeui.so.4.2.0 libkdeui.so )
 ( cd opt/kde/lib ; rm -rf libkjava.so.1 )
 ( cd opt/kde/lib ; ln -sf libkjava.so.1.0.0 libkjava.so.1 )
+( cd opt/kde/lib ; rm -rf libkspell2.so )
+( cd opt/kde/lib ; ln -sf libkspell2.so.1.0.0 libkspell2.so )
 ( cd opt/kde/lib ; rm -rf libkscript.so )
 ( cd opt/kde/lib ; ln -sf libkscript.so.0.0.0 libkscript.so )
+( cd opt/kde/lib ; rm -rf libknewstuff.so.1 )
+( cd opt/kde/lib ; ln -sf libknewstuff.so.1.0.0 libknewstuff.so.1 )
 ( cd opt/kde/lib ; rm -rf libkabc_net.so )
 ( cd opt/kde/lib ; ln -sf libkabc_net.so.1.0.0 libkabc_net.so )
 ( cd opt/kde/lib ; rm -rf libkdecore.so.4 )
@@ -81,6 +91,8 @@ fi
 ( cd opt/kde/lib ; ln -sf libkdefakes.so.4.2.0 libkdefakes.so.4 )
 ( cd opt/kde/lib ; rm -rf libkscreensaver.so )
 ( cd opt/kde/lib ; ln -sf libkscreensaver.so.4.2.0 libkscreensaver.so )
+( cd opt/kde/lib ; rm -rf libkimproxy.so.0 )
+( cd opt/kde/lib ; ln -sf libkimproxy.so.0.0.0 libkimproxy.so.0 )
 ( cd opt/kde/lib ; rm -rf libDCOP.so )
 ( cd opt/kde/lib ; ln -sf libDCOP.so.4.2.0 libDCOP.so )
 ( cd opt/kde/lib ; rm -rf libartskde.so )
@@ -113,6 +125,8 @@ fi
 ( cd opt/kde/lib ; ln -sf libkdefakes.so.4.2.0 libkdefakes.so )
 ( cd opt/kde/lib ; rm -rf libkmediaplayer.so.0 )
 ( cd opt/kde/lib ; ln -sf libkmediaplayer.so.0.0.0 libkmediaplayer.so.0 )
+( cd opt/kde/lib ; rm -rf libkspell2.so.1 )
+( cd opt/kde/lib ; ln -sf libkspell2.so.1.0.0 libkspell2.so.1 )
 ( cd opt/kde/lib ; rm -rf libkabc_net.so.1 )
 ( cd opt/kde/lib ; ln -sf libkabc_net.so.1.0.0 libkabc_net.so.1 )
 ( cd opt/kde/lib ; rm -rf libkwalletclient.so.1 )
