@@ -212,6 +212,8 @@ class KDialogBase : public KDialog
      *  @li @p Yes -     Show Yes-button.
      *  @li @p Stretch - Used internally. Ignored when used in a constructor.
      *  @li @p Filler  - Used internally. Ignored when used in a constructor.
+     *  @li @p NoDefault - Used when specifying a default button; indicates that
+     *                     no button should be marked by default.
      */
     enum ButtonCode
     {
@@ -229,7 +231,8 @@ class KDialogBase : public KDialog
       Yes     = 0x00000100,
       Details = 0x00000400,
       Filler  = 0x40000000,
-      Stretch = 0x80000000
+      Stretch = 0x80000000,
+      NoDefault             ///< @since 3.3
     };
 
     enum ActionButtonStyle
@@ -247,7 +250,8 @@ class KDialogBase : public KDialog
      *                    representation of the contents on the right side.
      *  @li @p Tabbed -   A dialog using a QTabWidget.
      *  @li @p Plain -    A normal dialog. Use plainPage() as parent for widgets.
-     *  @li @p Swallow
+     *  @li @p Swallow -  Simplifes the usage of existing widgets. You specify
+     *                    the widget to be displayed by setMainWidget().
      *  @li @p IconList - A dialog with an iconlist on the left side and a
      *                    representation of the contents on the right side.
      */
@@ -276,7 +280,8 @@ class KDialogBase : public KDialog
      * @param buttonMask Specifies which buttons will be visible. If zero
      *        (0) no button box will be made.
      * @param defaultButton Specifies which button will be marked as
-     *        the default.
+     *        the default. Use ButtonCode::NoDefault to indicate that no button
+     *        should be marked as the default button.
      * @param separator If @p true, a separator line is drawn between the
      *        action buttons and the main widget.
      * @param user1 User button1 item.
@@ -305,7 +310,8 @@ class KDialogBase : public KDialog
      * @param buttonMask Specifies which buttons will be visible. If zero
      *        (0) no button box will be made.
      * @param defaultButton Specifies which button will be marked as
-     *        the default.
+     *        the default. Use ButtonCode::NoDefault to indicate that no button
+     *        should be marked as the default button.
      * @param parent Parent of the dialog.
      * @param name Dialog name (for internal use only).
      * @param modal Controls dialog modality. If @p false, the rest of the
@@ -330,9 +336,9 @@ class KDialogBase : public KDialog
      * Constructor for the predefined layout mode where you specify the
      * kind of layout (face).
      *
-     * @param f widget flags, by default it is just set to WStyle_DialogBorder.
      * @param dialogFace You can use TreeList, Tabbed, Plain, Swallow or
      *        IconList.
+     * @param f widget flags, by default it is just set to WStyle_DialogBorder.
      * @param caption The dialog caption. Do not specify the application name
      *        here. The class will take care of that.
      * @param parent Parent of the dialog.
@@ -343,7 +349,8 @@ class KDialogBase : public KDialog
      * @param buttonMask Specifies which buttons will be visible. If zero
      *        (0) no button box will be made.
      * @param defaultButton Specifies which button will be marked as
-     *        the default.
+     *        the default. Use ButtonCode::NoDefault to indicate that no button
+     *        should be marked as the default button.
      * @param separator If @p true, a separator line is drawn between the
      *        action buttons and the main widget.
      * @param user1 User button1 text item.
@@ -377,7 +384,8 @@ class KDialogBase : public KDialog
      * @param buttonMask Specifies which buttons will be visible. If zero
      *        (0) no button box will be made.
      * @param defaultButton Specifies which button will be marked as
-     *        the default.
+     *        the default. Use ButtonCode::NoDefault to indicate that no button
+     *        should be marked as the default button.
      * @param escapeButton Specifies which button will be activated by
      *        when the dialog receives a @p Key_Escape keypress.
      * @param parent Parent of the dialog.
@@ -841,9 +849,7 @@ class KDialogBase : public KDialog
 
    /**
     * read the dialogs size from the configuration according to the screen size.
-    * If no size is saved for one dimension of the screen, a default size
-    * is chosen. The default width is 50 percent of the screen width, the
-    * default height is 40 percent of the screen height.
+    * If no size is saved for one dimension of the screen, sizeHint() is returned.
     *
     * @param groupName Name of the group to read from. The old group
     *                  of KGlobal::config is preserved.
@@ -852,9 +858,7 @@ class KDialogBase : public KDialog
 
    /**
     * read the dialogs size from the configuration according to the screen size.
-    * If no size is saved for one dimension of the screen, a default size
-    * is chosen. The default width is 50 percent of the screen width, the
-    * default height is 40 percent of the screen height.
+    * If no size is saved for one dimension of the screen, sizeHint() is returned.
     *
     * @param config The KConfig object to read from
     * @param groupName Name of the group to read from. The old group
@@ -996,6 +1000,18 @@ class KDialogBase : public KDialog
      */
     void setButtonWhatsThis( ButtonCode id, const QString &text );
 
+    /**
+     * Sets the KGuiItem directly for the button instead of using 3 methods to
+     * set the text, tooltip and whatsthis strings. This also allows to set an
+     * icon for the button which is otherwise not possible for the extra
+     * buttons beside Ok, Cancel and Apply.
+     *
+     * @param id The button identifier.
+     * @param item The KGuiItem for the button.
+     *
+     * @since 3.3
+     */
+    void setButtonGuiItem( ButtonCode id, const KGuiItem &item );
 
     /**
      * This function has only effect in TreeList mode.
@@ -1267,6 +1283,11 @@ class KDialogBase : public KDialog
      * @param anchor Defined anchor in your docbook sources
      * @param appname Defines the appname the help belongs to
      *                If empty it's the current one
+     *
+     * @note The help button works differently for the class
+     * KCMultiDialog, so it does not make sense to call this
+     * function for Dialogs of that type.  See
+     * KCMultiDialog::slotHelp() for more information.
      */
     void setHelp( const QString &anchor,
 		  const QString &appname = QString::null );
@@ -1383,7 +1404,7 @@ class KDialogBase : public KDialog
      * Do not use this signal. Is is kept for compatibility reasons.
      * @deprecated Use applyClicked() instead.
      */
-    void apply() KDE_DEPRECATED;
+    void apply();
 
     /**
      * The background tile has changed.
@@ -1422,7 +1443,8 @@ class KDialogBase : public KDialog
     void aboutToShowDetails();
 
     /**
-     * A page is about to be shown.
+     * A page is about to be shown. This signal is only emitted for the TreeList
+     * and IconList faces.
      */
     void aboutToShowPage(QWidget *page);
 
@@ -1527,7 +1549,7 @@ class KDialogBase : public KDialog
      * Do not use this slot. Is is kept for compatibility reasons.
      * Activated when the Apply button has been clicked
      */
-    virtual void applyPressed() KDE_DEPRECATED;
+    virtual void applyPressed();
 
     /**
      * Updates the margins and spacings.
@@ -1561,8 +1583,9 @@ class KDialogBase : public KDialog
      * only be ran once from the constructor.
      *
      * @param buttonMask Specifies what buttons will be made.
-     * @param defaultButton Specifies what button we be marked as the
-     * default.
+     * @param defaultButton Specifies which button will be marked as
+     *        the default. Use ButtonCode::NoDefault to indicate that no button
+     *        should be marked as the default button.
      * @param user1 User button1 item.
      * @param user2 User button2 item.
      * @param user2 User button3 item.
